LinkPeekModel class

Main Class for link peek information

Constructors

LinkPeekModel({String? url, String? domain, required String title, String? thumbnail, String? webIcon, Color? defaultColor, String? description, PaletteGenerator? colorScheme})
const

Properties

colorScheme → PaletteGenerator?
provides color scheme for the website
final
defaultColor → Color?
provides default color of the webpage (if available)
final
description → String?
provides description of the webpage (if available)
final
domain → String?
provides domain of the webpage
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → String?
provides thumbnail of the website (if available)
final
title → String
provides the title for the webpage
final
url → String?
provides full url of the page
final
webIcon → String?
provides icon of the webpage can be .svg .ico .png
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override